@@ -138,18 +138,8 @@ cheese_video_format_free (CheeseVideoFormat *format)
     g_slice_free (CheeseVideoFormat, format);
 }
 
-GType
-cheese_video_format_get_type (void)
-{
-  static GType our_type = 0;
-
-  if (G_UNLIKELY (our_type == 0))
-    our_type =
-      g_boxed_type_register_static ("CheeseVideoFormat",
-                                    (GBoxedCopyFunc) cheese_video_format_copy,
-                                    (GBoxedFreeFunc) cheese_video_format_free);
-  return our_type;
-}
+G_DEFINE_BOXED_TYPE (CheeseVideoFormat, cheese_video_format,
+    cheese_video_format_copy, cheese_video_format_free)
 
 /* the rest */
 
@@ -552,7 +542,9 @@ cheese_camera_device_class_init (CheeseCameraDeviceClass *klass)
                                                "Name of the device",
                                                "Human-readable name of the video capture device",
                                                NULL,
-                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                                               G_PARAM_READWRITE |
+                                               G_PARAM_CONSTRUCT_ONLY |
+                                               G_PARAM_STATIC_STRINGS);
 
   /**
    * CheeseCameraDevice:device-node:
@@ -563,7 +555,9 @@ cheese_camera_device_class_init (CheeseCameraDeviceClass *klass)
                                                       "Device node",
                                                       "Path to the device node of the video capture device",
                                                       NULL,
-                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                                                      G_PARAM_READWRITE |
+                                                      G_PARAM_CONSTRUCT_ONLY |
+                                                      G_PARAM_STATIC_STRINGS);
 
   /**
    * CheeseCameraDevice:uuid:
@@ -574,7 +568,9 @@ cheese_camera_device_class_init (CheeseCameraDeviceClass *klass)
                                                "Device UUID",
                                                "UUID of the video capture device",
                                                NULL,
-                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                                               G_PARAM_READWRITE |
+                                               G_PARAM_CONSTRUCT_ONLY |
+                                               G_PARAM_STATIC_STRINGS);
 
   /**
    * CheeseCameraDevice:v4l-api-version:
@@ -586,7 +582,9 @@ cheese_camera_device_class_init (CheeseCameraDeviceClass *klass)
                                                        "Video4Linux API version",
                                                        "Version of the Video4Linux API that the device supports",
                                                        1, 2, 2,
-                                                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                                                       G_PARAM_READWRITE |
+                                                       G_PARAM_CONSTRUCT_ONLY |
+                                                       G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST, properties);
 
