@@ -256,11 +256,7 @@ cheese_flash_dispose (GObject *object)
 {
   CheeseFlashPrivate *priv = CHEESE_FLASH (object)->priv;
 
-  if (priv->parent != NULL)
-  {
-    g_object_unref (priv->parent);
-    priv->parent = NULL;
-  }
+  g_clear_object (&priv->parent);
 
   if (G_OBJECT_CLASS (cheese_flash_parent_class)->dispose)
     G_OBJECT_CLASS (cheese_flash_parent_class)->dispose (object);
@@ -319,7 +315,8 @@ cheese_flash_class_init (CheeseFlashClass *klass)
                                                  "Parent widget",
                                                  "The flash will be fired on the screen where the parent widget is shown",
                                                  GTK_TYPE_WIDGET,
-                                                 G_PARAM_WRITABLE);
+                                                 G_PARAM_WRITABLE |
+                                                 G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST, properties);
 }
